{% extends "admin/base.html" %}
{% load i18n %}

{% block title %}{% translate 'Page not found' %}{% endblock %}

{% block content %}
  <div class="lucus-empty-state">
    <div class="lucus-empty-state__icon">404</div>
    <div class="lucus-empty-state__text">
      <h1>{% translate 'Page not found' %}</h1>
      <p>{% translate 'We’re sorry, but the requested page could not be found.' %}</p>
    </div>
  </div>
{% endblock %}
