{% extends "admin/base.html" %}
{% load i18n static %}

{% block title %}{% translate 'Password change' %}{% endblock %}

{% block breadcrumbs %}
  <div class="breadcrumbs">
    <a href="{% url 'admin:index' %}">{% translate 'Home' %}</a>
    &rsaquo; {% translate 'Password change' %}
  </div>
{% endblock %}

{% block content %}
<div id="content-main" class="lucus-content">
  <form method="post">{% csrf_token %}
    {% if form.errors %}
      <p class="errornote">
        {% blocktranslate count counter=form.errors.items|length %}Please correct the error below.{% plural %}Please correct the errors below.{% endblocktranslate %}
      </p>
    {% endif %}

    <p>{% translate 'Please enter your old password, for security’s sake, and then enter your new password twice so we can verify you typed it in correctly.' %}</p>

    <fieldset class="module aligned">
      <div class="form-row">
        {{ form.old_password.errors }}
        {{ form.old_password.label_tag }} {{ form.old_password }}
      </div>
      <div class="form-row">
        {{ form.new_password1.errors }}
        {{ form.new_password1.label_tag }} {{ form.new_password1 }}
        {% if form.new_password1.help_text %}
          <div class="help">{{ form.new_password1.help_text|safe }}</div>
        {% endif %}
      </div>
      <div class="form-row">
        {{ form.new_password2.errors }}
        {{ form.new_password2.label_tag }} {{ form.new_password2 }}
        {% if form.new_password2.help_text %}
          <div class="help">{{ form.new_password2.help_text|safe }}</div>
        {% endif %}
      </div>
    </fieldset>

    <div class="submit-row">
      <input type="submit" value="{% translate 'Change my password' %}" class="default">
    </div>
  </form>
</div>
{% endblock %}
