{% extends "admin/base.html" %}
{% load i18n static %}

{% block title %}{% translate 'Password change successful' %}{% endblock %}

{% block breadcrumbs %}
  <div class="breadcrumbs">
    <a href="{% url 'admin:index' %}">{% translate 'Home' %}</a>
    &rsaquo; {% translate 'Password change' %}
  </div>
{% endblock %}

{% block content %}
<div id="content-main" class="lucus-content">
  <h1>{% translate 'Password change successful' %}</h1>
  <p>{% translate 'Your password was changed.' %}</p>
</div>
{% endblock %}
